@@ -24,12 +24,18 @@ class DBBase:
         self.logger: Optional[Logger] = None
         self.connect = connect
         self._conn: Optional[Connection] = None
+        self._current_transaction: Optional[Transaction] = None
 
     @property
     def is_open(self) -> bool:
         """Returns True if the instance is connected."""
         return bool(self._conn)
 
+    @property
+    def is_in_transaction(self) -> bool:
+        """Returns True if the connection is in a transaction."""
+        return self._current_transaction is not None
+
     @property
     def conn(self) -> Connection:
         if self._conn is None:
@@ -79,9 +85,16 @@ class DBBase:
     @asynccontextmanager
     async def transaction(self) -> AsyncIterator[Transaction]:
         """Run a command in a database transaction."""
-        await self.auto_open()
-        async with self.conn.transaction() as trans:
-            yield trans
+        if self._current_transaction:
+            yield self._current_transaction
+        else:
+            await self.auto_open()
+            async with self.conn.transaction() as trans:
+                self._current_transaction = trans
+                try:
+                    yield trans
+                finally:
+                    self._current_transaction = None
 
     async def __aenter__(self) -> "DBBase":
         """Asynchronous context manager entry point."""
